@@ -15,6 +15,7 @@ from openstack.dns.v2 import recordset as _rs
 from openstack.dns.v2 import zone as _zone
 from openstack.dns.v2 import zone_export as _zone_export
 from openstack.dns.v2 import zone_import as _zone_import
+from openstack.dns.v2 import zone_share as _zone_share
 from openstack.dns.v2 import zone_transfer as _zone_transfer
 from openstack import proxy
 
@@ -26,6 +27,7 @@ class Proxy(proxy.Proxy):
         "zone": _zone.Zone,
         "zone_export": _zone_export.ZoneExport,
         "zone_import": _zone_import.ZoneImport,
+        "zone_share": _zone_share.ZoneShare,
         "zone_transfer_request": _zone_transfer.ZoneTransferRequest,
     }
 
@@ -69,7 +71,7 @@ class Proxy(proxy.Proxy):
         """
         return self._get(_zone.Zone, zone)
 
-    def delete_zone(self, zone, ignore_missing=True):
+    def delete_zone(self, zone, ignore_missing=True, delete_shares=False):
         """Delete a zone
 
         :param zone: The value can be the ID of a zone
@@ -79,11 +81,18 @@ class Proxy(proxy.Proxy):
             the zone does not exist.
             When set to ``True``, no exception will be set when attempting to
             delete a nonexistent zone.
+        :param bool delete_shares: When True, delete the zone shares along with
+                                   the zone.
 
         :returns: Zone been deleted
         :rtype: :class:`~openstack.dns.v2.zone.Zone`
         """
-        return self._delete(_zone.Zone, zone, ignore_missing=ignore_missing)
+        return self._delete(
+            _zone.Zone,
+            zone,
+            ignore_missing=ignore_missing,
+            delete_shares=delete_shares,
+        )
 
     def update_zone(self, zone, **attrs):
         """Update zone attributes
@@ -109,8 +118,9 @@ class Proxy(proxy.Proxy):
 
         :returns: :class:`~openstack.dns.v2.zone.Zone`
         """
-        return self._find(_zone.Zone, name_or_id,
-                          ignore_missing=ignore_missing)
+        return self._find(
+            _zone.Zone, name_or_id, ignore_missing=ignore_missing
+        )
 
     def abandon_zone(self, zone, **attrs):
         """Abandon Zone
@@ -220,10 +230,10 @@ class Proxy(proxy.Proxy):
         """
         if zone:
             zone = self._get_resource(_zone.Zone, zone)
-            recordset = self._get(
-                _rs.Recordset, recordset, zone_id=zone.id)
-        return self._delete(_rs.Recordset, recordset,
-                            ignore_missing=ignore_missing)
+            recordset = self._get(_rs.Recordset, recordset, zone_id=zone.id)
+        return self._delete(
+            _rs.Recordset, recordset, ignore_missing=ignore_missing
+        )
 
     def find_recordset(self, zone, name_or_id, ignore_missing=True, **query):
         """Find a single recordset
@@ -273,8 +283,9 @@ class Proxy(proxy.Proxy):
         :returns: The results of zone creation.
         :rtype: :class:`~openstack.dns.v2.zone_import.ZoneImport`
         """
-        return self._create(_zone_import.ZoneImport, prepend_key=False,
-                            **attrs)
+        return self._create(
+            _zone_import.ZoneImport, prepend_key=False, **attrs
+        )
 
     def get_zone_import(self, zone_import):
         """Get a zone import record
@@ -299,8 +310,9 @@ class Proxy(proxy.Proxy):
 
         :returns: None
         """
-        return self._delete(_zone_import.ZoneImport, zone_import,
-                            ignore_missing=ignore_missing)
+        return self._delete(
+            _zone_import.ZoneImport, zone_import, ignore_missing=ignore_missing
+        )
 
     # ======== Zone Exports ========
     def zone_exports(self, **query):
@@ -330,11 +342,13 @@ class Proxy(proxy.Proxy):
         :rtype: :class:`~openstack.dns.v2.zone_export.ZoneExport`
         """
         zone = self._get_resource(_zone.Zone, zone)
-        return self._create(_zone_export.ZoneExport,
-                            base_path='/zones/%(zone_id)s/tasks/export',
-                            prepend_key=False,
-                            zone_id=zone.id,
-                            **attrs)
+        return self._create(
+            _zone_export.ZoneExport,
+            base_path='/zones/%(zone_id)s/tasks/export',
+            prepend_key=False,
+            zone_id=zone.id,
+            **attrs,
+        )
 
     def get_zone_export(self, zone_export):
         """Get a zone export record
@@ -354,8 +368,11 @@ class Proxy(proxy.Proxy):
         :returns: ZoneExport instance.
         :rtype: :class:`~openstack.dns.v2.zone_export.ZoneExport`
         """
-        return self._get(_zone_export.ZoneExport, zone_export,
-                         base_path='/zones/tasks/export/%(id)s/export')
+        return self._get(
+            _zone_export.ZoneExport,
+            zone_export,
+            base_path='/zones/tasks/export/%(id)s/export',
+        )
 
     def delete_zone_export(self, zone_export, ignore_missing=True):
         """Delete a zone export
@@ -370,8 +387,9 @@ class Proxy(proxy.Proxy):
 
         :returns: None
         """
-        return self._delete(_zone_export.ZoneExport, zone_export,
-                            ignore_missing=ignore_missing)
+        return self._delete(
+            _zone_export.ZoneExport, zone_export, ignore_missing=ignore_missing
+        )
 
     # ======== FloatingIPs ========
     def floating_ips(self, **query):
@@ -468,7 +486,8 @@ class Proxy(proxy.Proxy):
             base_path='/zones/%(zone_id)s/tasks/transfer_requests',
             prepend_key=False,
             zone_id=zone.id,
-            **attrs)
+            **attrs,
+        )
 
     def update_zone_transfer_request(self, request, **attrs):
         """Update ZoneTransfer Request attributes
@@ -480,8 +499,9 @@ class Proxy(proxy.Proxy):
 
         :rtype: :class:`~openstack.dns.v2.zone_transfer.ZoneTransferRequest`
         """
-        return self._update(_zone_transfer.ZoneTransferRequest,
-                            request, **attrs)
+        return self._update(
+            _zone_transfer.ZoneTransferRequest, request, **attrs
+        )
 
     def delete_zone_transfer_request(self, request, ignore_missing=True):
         """Delete a ZoneTransfer Request
@@ -497,8 +517,11 @@ class Proxy(proxy.Proxy):
 
         :returns: None
         """
-        return self._delete(_zone_transfer.ZoneTransferRequest, request,
-                            ignore_missing=ignore_missing)
+        return self._delete(
+            _zone_transfer.ZoneTransferRequest,
+            request,
+            ignore_missing=ignore_missing,
+        )
 
     def zone_transfer_accepts(self, **query):
         """Retrieve a generator of zone transfer accepts
@@ -536,17 +559,115 @@ class Proxy(proxy.Proxy):
         """
         return self._create(_zone_transfer.ZoneTransferAccept, **attrs)
 
+    # ======== Zone Shares ========
+    def zone_shares(self, zone, **query):
+        """Retrieve a generator of zone sharess
+
+        :param zone: The zone ID or a
+            :class:`~openstack.dns.v2.zone.Zone` instance
+        :param dict query: Optional query parameters to be sent to limit the
+                           resources being returned.
+
+                           * `target_project_id`: The target project ID field.
+
+        :returns: A generator of zone shares
+            :class:`~openstack.dns.v2.zone_share.ZoneShare` instances.
+        """
+        zone_obj = self._get_resource(_zone.Zone, zone)
+        return self._list(_zone_share.ZoneShare, zone_id=zone_obj.id, **query)
+
+    def get_zone_share(self, zone, zone_share):
+        """Get a zone share
+
+        :param zone: The value can be the ID of a zone
+            or a :class:`~openstack.dns.v2.zone.Zone` instance.
+        :param zone_share: The zone_share can be either the ID of the zone
+            share or a :class:`~openstack.dns.v2.zone_share.ZoneShare` instance
+            that the zone share belongs to.
+
+        :returns: ZoneShare instance.
+        :rtype: :class:`~openstack.dns.v2.zone_share.ZoneShare`
+        """
+        zone_obj = self._get_resource(_zone.Zone, zone)
+        return self._get(
+            _zone_share.ZoneShare, zone_share, zone_id=zone_obj.id
+        )
+
+    def find_zone_share(self, zone, zone_share_id, ignore_missing=True):
+        """Find a single zone share
+
+        :param zone: The value can be the ID of a zone
+            or a :class:`~openstack.dns.v2.zone.Zone` instance.
+        :param zone_share_id: The zone share ID
+        :param bool ignore_missing: When set to ``False``
+            :class:`~openstack.exceptions.ResourceNotFound` will be raised
+            when the zone share does not exist.
+            When set to ``True``,  None will be returned when attempting to
+            find a nonexistent zone share.
+
+        :returns: :class:`~openstack.dns.v2.zone_share.ZoneShare`
+        """
+        zone_obj = self._get_resource(_zone.Zone, zone)
+        return self._find(
+            _zone_share.ZoneShare,
+            zone_share_id,
+            ignore_missing=ignore_missing,
+            zone_id=zone_obj.id,
+        )
+
+    def create_zone_share(self, zone, **attrs):
+        """Create a new zone share from attributes
+
+        :param zone: The zone ID or a
+            :class:`~openstack.dns.v2.zone.Zone` instance
+        :param dict attrs: Keyword arguments which will be used to create
+            a :class:`~openstack.dns.v2.zone_share.ZoneShare`,
+            comprised of the properties on the ZoneShare class.
+
+        :returns: The results of zone share creation
+        :rtype: :class:`~openstack.dns.v2.zone_share.ZoneShare`
+        """
+        zone_obj = self._get_resource(_zone.Zone, zone)
+        return self._create(
+            _zone_share.ZoneShare, zone_id=zone_obj.id, **attrs
+        )
+
+    def delete_zone_share(self, zone, zone_share, ignore_missing=True):
+        """Delete a zone share
+
+        :param zone: The zone ID or a
+            :class:`~openstack.dns.v2.zone.Zone` instance
+        :param zone_share: The zone_share can be either the ID of the zone
+            share or a :class:`~openstack.dns.v2.zone_share.ZoneShare` instance
+            that the zone share belongs to.
+        :param bool ignore_missing: When set to ``False``
+            :class:`~openstack.exceptions.ResourceNotFound` will be raised when
+            the zone share does not exist.
+            When set to ``True``, no exception will be set when attempting to
+            delete a nonexistent zone share.
+
+        :returns: ``None``
+        """
+        zone_obj = self._get_resource(_zone.Zone, zone)
+        self._delete(
+            _zone_share.ZoneShare,
+            zone_share,
+            ignore_missing=ignore_missing,
+            zone_id=zone_obj.id,
+        )
+
     def _get_cleanup_dependencies(self):
         # DNS may depend on floating ip
-        return {
-            'dns': {
-                'before': ['network']
-            }
-        }
+        return {'dns': {'before': ['network']}}
 
-    def _service_cleanup(self, dry_run=True, client_status_queue=False,
-                         identified_resources=None,
-                         filters=None, resource_evaluation_fn=None):
+    def _service_cleanup(
+        self,
+        dry_run=True,
+        client_status_queue=False,
+        identified_resources=None,
+        filters=None,
+        resource_evaluation_fn=None,
+    ):
         # Delete all zones
         for obj in self.zones():
             self._service_cleanup_del_res(
@@ -556,7 +677,8 @@ class Proxy(proxy.Proxy):
                 client_status_queue=client_status_queue,
                 identified_resources=identified_resources,
                 filters=filters,
-                resource_evaluation_fn=resource_evaluation_fn)
+                resource_evaluation_fn=resource_evaluation_fn,
+            )
         # Unset all floatingIPs
         # NOTE: FloatingIPs are not cleaned when filters are set
         for obj in self.floating_ips():
@@ -567,4 +689,5 @@ class Proxy(proxy.Proxy):
                 client_status_queue=client_status_queue,
                 identified_resources=identified_resources,
                 filters=filters,
-                resource_evaluation_fn=resource_evaluation_fn)
+                resource_evaluation_fn=resource_evaluation_fn,
+            )
