@@ -27,6 +27,7 @@ from openstack.image.v2 import task as _task
 from openstack import proxy
 from openstack import resource
 from openstack import utils
+from openstack import warnings as os_warnings
 
 # Rackspace returns this for intermittent import errors
 _IMAGE_ERROR_396 = "Image cannot be imported. Error code: '396'"
@@ -49,12 +50,13 @@ def _get_name_and_filename(name, image_format):
 
 
 class Proxy(proxy.Proxy):
-
     _resource_registry = {
         "cache": _cache.Cache,
         "image": _image.Image,
         "image_member": _member.Member,
         "metadef_namespace": _metadef_namespace.MetadefNamespace,
+        "metadef_resource_type": _metadef_resource_type.MetadefResourceType,
+        "metadef_resource_type_association": _metadef_resource_type.MetadefResourceTypeAssociation,  # noqa
         "schema": _schema.Schema,
         "info_import": _si.Import,
         "info_store": _si.Store,
@@ -97,7 +99,7 @@ class Proxy(proxy.Proxy):
         return cache.queue(self, image_id)
 
     def clear_cache(self, target):
-        """ Clear all images from cache, queue or both
+        """Clear all images from cache, queue or both
 
         :param target: Specify which target you want to clear
             One of: ``both``(default), ``cache``, ``queue``.
@@ -333,6 +335,8 @@ class Proxy(proxy.Proxy):
                 **image_kwargs,
             )
         else:
+            properties = image_kwargs.pop('properties', {})
+            image_kwargs.update(self._make_v2_image_params(meta, properties))
             image_kwargs['name'] = name
             image = self._create(_image.Image, **image_kwargs)
 
@@ -499,7 +503,10 @@ class Proxy(proxy.Proxy):
         :returns: The results of image creation
         :rtype: :class:`~openstack.image.v2.image.Image`
         """
-        warnings.warn("upload_image is deprecated. Use create_image instead.")
+        warnings.warn(
+            "upload_image is deprecated. Use create_image instead.",
+            os_warnings.OpenStackDeprecationWarning,
+        )
         # container_format and disk_format are required to be set
         # on the image by the time upload_image is called, but they're not
         # required by the _create call. Enforce them here so that we don't
@@ -997,6 +1004,10 @@ class Proxy(proxy.Proxy):
             a :class:`~openstack.image.v2.member.Member`,
             comprised of the properties on the Member class.
 
+        See `Image Sharing Reference
+        <https://docs.openstack.org/api-ref/image/v2/index.html?expanded=create-image-member-detail#create-image-member>`__
+        for details.
+
         :returns: The results of member creation
         :rtype: :class:`~openstack.image.v2.member.Member`
         """
@@ -1093,6 +1104,10 @@ class Proxy(proxy.Proxy):
         :param attrs: The attributes to update on the member represented
             by ``member``.
 
+        See `Image Sharing Reference
+        <https://docs.openstack.org/api-ref/image/v2/index.html?expanded=update-image-member-detail#update-image-member>`__
+        for details.
+
         :returns: The updated member
         :rtype: :class:`~openstack.image.v2.member.Member`
         """
