@@ -11,6 +11,11 @@
 # under the License.
 
 import functools
+from typing import Generator
+from typing import Generic
+from typing import Optional
+from typing import Type
+from typing import TypeVar
 import urllib
 from urllib.parse import urlparse
 
@@ -28,6 +33,8 @@ from openstack import _log
 from openstack import exceptions
 from openstack import resource
 
+T = TypeVar('T')
+
 
 # The _check_resource decorator is used on Proxy methods to ensure that
 # the `actual` argument is in fact the type of the `expected` argument.
@@ -67,7 +74,7 @@ def normalize_metric_name(name):
     return name
 
 
-class Proxy(adapter.Adapter):
+class Proxy(adapter.Adapter, Generic[T]):
     """Represents a service."""
 
     retriable_status_codes = None
@@ -100,7 +107,7 @@ class Proxy(adapter.Adapter):
         kwargs.setdefault(
             'retriable_status_codes', self.retriable_status_codes
         )
-        super(Proxy, self).__init__(session=session, *args, **kwargs)
+        super().__init__(session=session, *args, **kwargs)
         self._statsd_client = statsd_client
         self._statsd_prefix = statsd_prefix
         self._prometheus_counter = prometheus_counter
@@ -166,7 +173,7 @@ class Proxy(adapter.Adapter):
                 # Get from cache or execute and cache
                 response = conn._cache.get_or_create(
                     key=key,
-                    creator=super(Proxy, self).request,
+                    creator=super().request,
                     creator_args=(
                         [url, method],
                         dict(
@@ -183,7 +190,7 @@ class Proxy(adapter.Adapter):
                 # asked for cache bypass
                 self._invalidate_cache(conn, key_prefix)
                 # Pass through the API request bypassing cache
-                response = super(Proxy, self).request(
+                response = super().request(
                     url,
                     method,
                     connect_retries=connect_retries,
@@ -430,14 +437,14 @@ class Proxy(adapter.Adapter):
             self, '_connection', getattr(self.session, '_sdk_connection', None)
         )
 
-    def _get_resource(self, resource_type, value, **attrs):
+    def _get_resource(self, resource_type: Type[T], value, **attrs) -> T:
         """Get a resource object to work on
 
         :param resource_type: The type of resource to operate on. This should
             be a subclass of :class:`~openstack.resource.Resource` with a
             ``from_id`` method.
         :param value: The ID of a resource or an object of ``resource_type``
-            class if using an existing instance, or ``munch.Munch``,
+            class if using an existing instance, or ``utils.Munch``,
             or None to create a new instance.
         :param attrs: A dict containing arguments for forming the request
             URL, if needed.
@@ -476,7 +483,9 @@ class Proxy(adapter.Adapter):
             value = resource.Resource._get_id(parent)
         return value
 
-    def _find(self, resource_type, name_or_id, ignore_missing=True, **attrs):
+    def _find(
+        self, resource_type: Type[T], name_or_id, ignore_missing=True, **attrs
+    ) -> Optional[T]:
         """Find a resource
 
         :param name_or_id: The name or ID of a resource to find.
@@ -496,7 +505,9 @@ class Proxy(adapter.Adapter):
         )
 
     @_check_resource(strict=False)
-    def _delete(self, resource_type, value, ignore_missing=True, **attrs):
+    def _delete(
+        self, resource_type: Type[T], value, ignore_missing=True, **attrs
+    ):
         """Delete a resource
 
         :param resource_type: The type of resource to delete. This should
@@ -532,7 +543,9 @@ class Proxy(adapter.Adapter):
         return rv
 
     @_check_resource(strict=False)
-    def _update(self, resource_type, value, base_path=None, **attrs):
+    def _update(
+        self, resource_type: Type[T], value, base_path=None, **attrs
+    ) -> T:
         """Update a resource
 
         :param resource_type: The type of resource to update.
@@ -556,7 +569,7 @@ class Proxy(adapter.Adapter):
         res = self._get_resource(resource_type, value, **attrs)
         return res.commit(self, base_path=base_path)
 
-    def _create(self, resource_type, base_path=None, **attrs):
+    def _create(self, resource_type: Type[T], base_path=None, **attrs):
         """Create a resource from attributes
 
         :param resource_type: The type of resource to create.
@@ -580,7 +593,9 @@ class Proxy(adapter.Adapter):
         res = resource_type.new(connection=conn, **attrs)
         return res.create(self, base_path=base_path)
 
-    def _bulk_create(self, resource_type, data, base_path=None):
+    def _bulk_create(
+        self, resource_type: Type[T], data, base_path=None
+    ) -> Generator[T, None, None]:
         """Create a resource from attributes
 
         :param resource_type: The type of resource to create.
@@ -603,7 +618,7 @@ class Proxy(adapter.Adapter):
     @_check_resource(strict=False)
     def _get(
         self,
-        resource_type,
+        resource_type: Type[T],
         value=None,
         requires_id=True,
         base_path=None,
@@ -646,12 +661,12 @@ class Proxy(adapter.Adapter):
 
     def _list(
         self,
-        resource_type,
+        resource_type: Type[T],
         paginated=True,
         base_path=None,
         jmespath_filters=None,
         **attrs
-    ):
+    ) -> Generator[T, None, None]:
         """List a resource
 
         :param resource_type: The type of resource to list. This should
@@ -677,10 +692,8 @@ class Proxy(adapter.Adapter):
             :class:`~openstack.resource.Resource` that doesn't match
             the ``resource_type``.
         """
-
         data = resource_type.list(
-            self, paginated=paginated, base_path=base_path,
-            **attrs
+            self, paginated=paginated, base_path=base_path, **attrs
         )
 
         if jmespath_filters and isinstance(jmespath_filters, str):
@@ -688,7 +701,9 @@ class Proxy(adapter.Adapter):
 
         return data
 
-    def _head(self, resource_type, value=None, base_path=None, **attrs):
+    def _head(
+        self, resource_type: Type[T], value=None, base_path=None, **attrs
+    ):
         """Retrieve a resource's header
 
         :param resource_type: The type of resource to retrieve.
@@ -800,6 +815,8 @@ class Proxy(adapter.Adapter):
             return False
 
 
+# TODO(stephenfin): Remove this and all users. Use of this generally indicates
+# a missing Resource type.
 def _json_response(response, result_key=None, error_message=None):
     """Temporary method to use to bridge from ShadeAdapter to SDK calls."""
     exceptions.raise_from_response(response, error_message=error_message)
@@ -817,11 +834,3 @@ def _json_response(response, result_key=None, error_message=None):
     except JSONDecodeError:
         return response
     return result_json
-
-
-class _ShadeAdapter(Proxy):
-    """Wrapper for shade methods that expect json unpacking."""
-
-    def request(self, url, method, error_message=None, **kwargs):
-        response = super(_ShadeAdapter, self).request(url, method, **kwargs)
-        return _json_response(response, error_message=error_message)
