@@ -87,7 +87,6 @@ def _convert_type(value, data_type, list_type=None):
 
 
 class _BaseComponent:
-
     # The name this component is being tracked as in the Resource
     key = None
     # The class to be used for mappings
@@ -99,7 +98,7 @@ class _BaseComponent:
     deprecation_reason = None
 
     #: Control field used to manage the deprecation warning. We want to warn
-    # only once when the attribute is retrieved in the code.
+    #: only once when the attribute is retrieved in the code.
     already_warned_deprecation = False
 
     def __init__(
@@ -207,15 +206,14 @@ class _BaseComponent:
     def warn_if_deprecated_property(self, value):
         deprecated = object.__getattribute__(self, 'deprecated')
         deprecation_reason = object.__getattribute__(
-            self, 'deprecation_reason',
+            self,
+            'deprecation_reason',
         )
 
         if value and deprecated:
             warnings.warn(
-                "The field %r has been deprecated. %s" % (
-                    self.name,
-                    deprecation_reason or "Avoid usage."
-                ),
+                "The field %r has been deprecated. %s"
+                % (self.name, deprecation_reason or "Avoid usage."),
                 os_warnings.RemovedFieldWarning,
             )
         return value
@@ -1009,7 +1007,8 @@ class Resource(dict):
         return cls(_synchronized=synchronized, connection=connection, **obj)
 
     def _attr_to_dict(self, attr, to_munch):
-        """For a given attribute, convert it into a form suitable for a dict value.
+        """For a given attribute, convert it into a form suitable for a dict
+        value.
 
         :param bool attr: Attribute name to convert
 
@@ -1026,9 +1025,7 @@ class Resource(dict):
             converted = []
             for raw in value:
                 if isinstance(raw, Resource):
-                    converted.append(
-                        raw.to_dict(_to_munch=to_munch)
-                    )
+                    converted.append(raw.to_dict(_to_munch=to_munch))
                 elif isinstance(raw, dict) and to_munch:
                     converted.append(utils.Munch(raw))
                 else:
@@ -1152,7 +1149,13 @@ class Resource(dict):
         body['properties'] = props
         return body
 
-    def _prepare_request_body(self, patch, prepend_key):
+    def _prepare_request_body(
+        self,
+        patch,
+        prepend_key,
+        *,
+        resource_request_key=None,
+    ):
         if patch:
             if not self._store_unknown_attrs_as_properties:
                 # Default case
@@ -1180,8 +1183,11 @@ class Resource(dict):
                     self._body.dirty
                 )
 
-            if prepend_key and self.resource_key is not None:
-                body = {self.resource_key: body}
+            if prepend_key:
+                if resource_request_key is not None:
+                    body = {resource_request_key: body}
+                elif self.resource_key is not None:
+                    body = {self.resource_key: body}
         return body
 
     def _prepare_request(
@@ -1191,6 +1197,8 @@ class Resource(dict):
         patch=False,
         base_path=None,
         params=None,
+        *,
+        resource_request_key=None,
         **kwargs,
     ):
         """Prepare a request to be sent to the server
@@ -1210,7 +1218,11 @@ class Resource(dict):
         if requires_id is None:
             requires_id = self.requires_id
 
-        body = self._prepare_request_body(patch, prepend_key)
+        # Conditionally construct arguments for _prepare_request_body
+        request_kwargs = {"patch": patch, "prepend_key": prepend_key}
+        if resource_request_key is not None:
+            request_kwargs['resource_request_key'] = resource_request_key
+        body = self._prepare_request_body(**request_kwargs)
 
         # TODO(mordred) Ensure headers have string values better than this
         headers = {}
@@ -1237,7 +1249,14 @@ class Resource(dict):
 
         return _Request(uri, body, headers)
 
-    def _translate_response(self, response, has_body=None, error_message=None):
+    def _translate_response(
+        self,
+        response,
+        has_body=None,
+        error_message=None,
+        *,
+        resource_response_key=None,
+    ):
         """Given a KSA response, inflate this instance with its data
 
         DELETE operations don't return a body, so only try to work
@@ -1254,7 +1273,9 @@ class Resource(dict):
         if has_body:
             try:
                 body = response.json()
-                if self.resource_key and self.resource_key in body:
+                if resource_response_key and resource_response_key in body:
+                    body = body[resource_response_key]
+                elif self.resource_key and self.resource_key in body:
                     body = body[self.resource_key]
 
                 # Do not allow keys called "self" through. Glance chose
@@ -1412,8 +1433,10 @@ class Resource(dict):
         prepend_key=True,
         base_path=None,
         *,
+        resource_request_key=None,
+        resource_response_key=None,
         microversion=None,
-        **params
+        **params,
     ):
         """Create a remote resource based on this instance.
 
@@ -1424,6 +1447,12 @@ class Resource(dict):
             True.
         :param str base_path: Base part of the URI for creating resources, if
             different from :data:`~openstack.resource.Resource.base_path`.
+        :param str resource_request_key: Overrides the usage of
+            self.resource_key when prepending a key to the request body.
+            Ignored if `prepend_key` is false.
+        :param str resource_response_key: Overrides the usage of
+            self.resource_key when processing response bodies.
+            Ignored if `prepend_key` is false.
         :param str microversion: API version to override the negotiated one.
         :param dict params: Additional params to pass.
         :return: This :class:`Resource` instance.
@@ -1442,15 +1471,20 @@ class Resource(dict):
             else self.create_method == 'PUT'
         )
 
+        # Construct request arguments.
+        request_kwargs = {
+            "requires_id": requires_id,
+            "prepend_key": prepend_key,
+            "base_path": base_path,
+        }
+        if resource_request_key is not None:
+            request_kwargs['resource_request_key'] = resource_request_key
+
         if self.create_exclude_id_from_body:
             self._body._dirty.discard("id")
 
         if self.create_method == 'PUT':
-            request = self._prepare_request(
-                requires_id=requires_id,
-                prepend_key=prepend_key,
-                base_path=base_path,
-            )
+            request = self._prepare_request(**request_kwargs)
             response = session.put(
                 request.url,
                 json=request.body,
@@ -1459,11 +1493,7 @@ class Resource(dict):
                 params=params,
             )
         elif self.create_method == 'POST':
-            request = self._prepare_request(
-                requires_id=requires_id,
-                prepend_key=prepend_key,
-                base_path=base_path,
-            )
+            request = self._prepare_request(**request_kwargs)
             response = session.post(
                 request.url,
                 json=request.body,
@@ -1482,11 +1512,21 @@ class Resource(dict):
             else self.create_returns_body
         )
         self.microversion = microversion
-        self._translate_response(response, has_body=has_body)
+
+        response_kwargs = {
+            "has_body": has_body,
+        }
+        if resource_response_key is not None:
+            response_kwargs['resource_response_key'] = resource_response_key
+
+        self._translate_response(response, **response_kwargs)
         # direct comparision to False since we need to rule out None
         if self.has_body and self.create_returns_body is False:
             # fetch the body if it's required but not returned by create
-            return self.fetch(session)
+            fetch_kwargs = {}
+            if resource_response_key is not None:
+                fetch_kwargs = {'resource_response_key': resource_response_key}
+            return self.fetch(session, **fetch_kwargs)
         return self
 
     @classmethod
@@ -1603,6 +1643,7 @@ class Resource(dict):
         error_message=None,
         skip_cache=False,
         *,
+        resource_response_key=None,
         microversion=None,
         **params,
     ):
@@ -1618,6 +1659,8 @@ class Resource(dict):
             requested object does not exist.
         :param bool skip_cache: A boolean indicating whether optional API
             cache should be skipped for this invocation.
+        :param str resource_response_key: Overrides the usage of
+            self.resource_key when processing the response body.
         :param str microversion: API version to override the negotiated one.
         :param dict params: Additional parameters that can be consumed.
         :return: This :class:`Resource` instance.
@@ -1630,7 +1673,8 @@ class Resource(dict):
             raise exceptions.MethodNotSupported(self, 'fetch')
 
         request = self._prepare_request(
-            requires_id=requires_id, base_path=base_path,
+            requires_id=requires_id,
+            base_path=base_path,
         )
         session = self._get_session(session)
         if microversion is None:
@@ -1646,6 +1690,8 @@ class Resource(dict):
             kwargs['error_message'] = error_message
 
         self.microversion = microversion
+        if resource_response_key is not None:
+            kwargs['resource_response_key'] = resource_response_key
         self._translate_response(response, **kwargs)
         return self
 
@@ -1878,8 +1924,9 @@ class Resource(dict):
             retry_on_conflict=retry_on_conflict,
         )
 
-    def delete(self, session, error_message=None, *, microversion=None,
-               **kwargs):
+    def delete(
+        self, session, error_message=None, *, microversion=None, **kwargs
+    ):
         """Delete the remote resource based on this instance.
 
         :param session: The session to use for making this request.
@@ -1895,8 +1942,9 @@ class Resource(dict):
             the resource was not found.
         """
 
-        response = self._raw_delete(session, microversion=microversion,
-                                    **kwargs)
+        response = self._raw_delete(
+            session, microversion=microversion, **kwargs
+        )
         kwargs = {}
         if error_message:
             kwargs['error_message'] = error_message
@@ -1982,7 +2030,7 @@ class Resource(dict):
         )
         client_filters = dict()
         # Gather query parameters which are not supported by the server
-        for (k, v) in params.items():
+        for k, v in params.items():
             if (
                 # Known attr
                 hasattr(cls, k)
@@ -2063,7 +2111,8 @@ class Resource(dict):
                 for key in client_filters.keys():
                     if isinstance(client_filters[key], dict):
                         if not _dict_filter(
-                                client_filters[key], value.get(key, None)):
+                            client_filters[key], value.get(key, None)
+                        ):
                             filters_matched = False
                             break
                     elif value.get(key, None) != client_filters[key]:
@@ -2123,7 +2172,7 @@ class Resource(dict):
             # Glance has a next field in the main body
             next_link = next_link or data.get('next')
             if next_link and next_link.startswith('/v'):
-                next_link = next_link[next_link.find('/', 1):]
+                next_link = next_link[next_link.find('/', 1) :]
 
         if not next_link and 'next' in response.links:
             # RFC5988 specifies Link headers and requests parses them if they
@@ -2228,8 +2277,11 @@ class Resource(dict):
                 **params,
             )
             return match.fetch(session, microversion=microversion, **params)
-        except (exceptions.NotFoundException, exceptions.BadRequestException,
-                exceptions.ForbiddenException):
+        except (
+            exceptions.NotFoundException,
+            exceptions.BadRequestException,
+            exceptions.ForbiddenException,
+        ):
             # NOTE(gtema): There are few places around openstack that return
             # 400 if we try to GET resource and it doesn't exist.
             pass
@@ -2277,6 +2329,7 @@ def wait_for_status(
     interval=None,
     wait=None,
     attribute='status',
+    callback=None,
 ):
     """Wait for the resource to be in a particular status.
 
@@ -2293,6 +2346,9 @@ def wait_for_status(
     :param wait: Maximum number of seconds to wait for transition.
         Set to ``None`` to wait forever.
     :param attribute: Name of the resource attribute that contains the status.
+    :param callback: A callback function. This will be called with a single
+        value, progress. This is API specific but is generally a percentage
+        value from 0-100.
 
     :return: The updated resource.
     :raises: :class:`~openstack.exceptions.ResourceTimeout` transition
@@ -2320,7 +2376,6 @@ def wait_for_status(
         timeout=wait, message=msg, wait=interval
     ):
         resource = resource.fetch(session, skip_cache=True)
-
         if not resource:
             raise exceptions.ResourceFailure(
                 "{name} went away while waiting for {status}".format(
@@ -2347,8 +2402,12 @@ def wait_for_status(
             new_status,
         )
 
+        if callback:
+            progress = getattr(resource, 'progress', None) or 0
+            callback(progress)
 
-def wait_for_delete(session, resource, interval, wait):
+
+def wait_for_delete(session, resource, interval, wait, callback=None):
     """Wait for the resource to be deleted.
 
     :param session: The session to use for making this request.
@@ -2357,6 +2416,9 @@ def wait_for_delete(session, resource, interval, wait):
     :type resource: :class:`~openstack.resource.Resource`
     :param interval: Number of seconds to wait between checks.
     :param wait: Maximum number of seconds to wait for the delete.
+    :param callback: A callback function. This will be called with a single
+        value, progress. This is API specific but is generally a percentage
+        value from 0-100.
 
     :return: Method returns self on success.
     :raises: :class:`~openstack.exceptions.ResourceTimeout` transition
@@ -2378,3 +2440,7 @@ def wait_for_delete(session, resource, interval, wait):
                 return resource
         except exceptions.NotFoundException:
             return orig_resource
+
+        if callback:
+            progress = getattr(resource, 'progress', None) or 0
+            callback(progress)
